@@ -18,7 +18,7 @@ use Test::BrewBuild::BrewCommands;
 use Test::BrewBuild::Dispatch;
 use Test::BrewBuild::Tester;
 
-our $VERSION = '2.08';
+our $VERSION = '2.09';
 
 my $log;
 my $bcmd;
@@ -53,14 +53,13 @@ sub new {
 }
 sub options {
     my ($self, $args) = @_;
-    my (%opts, $help, $setup);
-
+    my %opts;
     my $bad_opt = _validate_opts($args);
 
     GetOptionsFromArray(
         $args,
         "on=s@"         => \$opts{on},
-        "n|new=i"       => \$opts{new},
+        "n|new=s"       => \$opts{new},
         "r|remove"      => \$opts{remove},
         "R|revdep"      => \$opts{revdep},
         "plugin=s"      => \$opts{plugin},
@@ -73,8 +72,8 @@ sub options {
         "T|selftest"    => \$opts{selftest},
         "D|dispatch"    => \$opts{dispatch},
         "t|tester=s@"   => \$opts{testers},
-        "s|setup"       => \$setup,
-        "h|help"        => \$help,
+        "s|setup"       => \$opts{setup},
+        "h|help"        => \$opts{help},
     );
 
     $opts{error} = 1 if $bad_opt;
@@ -447,8 +446,8 @@ Local usage options:
 -n | --new      How many random versions of perl to install (-1 to install all)
 -r | --remove   Remove all installed perls (less the current one)
 -i | --install  Number portion of an available perl version according to "*brew available". Multiple versions can be sent in at once
+-S | --save     By default, we save only FAIL logs. This will also save the PASS logs
 -N | --notest   Do not run tests. Allows you to --remove and --install without testing
--l | --legacy   Operate on perls < 5.8.x. The default plugins won't work with this flag set if a lower version is installed
 
 Network dispatching options:
 
@@ -464,6 +463,7 @@ Special options:
 
 -p | --plugin   Module name of the exec command plugin to use
 -a | --args     List of args to pass into the plugin (one arg per loop)
+-l | --legacy   Operate on perls < 5.8.x. The default plugins won't work with this flag set if a lower version is installed
 -T | --selftest Testing only: prevent recursive testing on Test::BrewBuild
 -d | --debug    0-7, sets logging verbosity, default is 0
 
@@ -850,10 +850,10 @@ sub _validate_opts {
     );
 
     my $bad_opt = 0;
-
+    my $i;
     if (@$args) {
-        my @args = grep /^-/, @$args;
-        for my $arg (@args) {
+        my @params = grep {++$i % 2 != 0} @$args;
+        for my $arg (@params) {
             $arg =~ s/^-{1,2}//g;
             if (!grep { $arg eq $_ } @valid_args) {
                 $bad_opt = 1;
