@@ -4,7 +4,7 @@ use warnings;
 
 use Capture::Tiny qw(:all);
 
-our $VERSION = '2.08';
+our $VERSION = '2.09';
 
 sub new {
     return bless {}, shift;
@@ -50,9 +50,9 @@ sub pull {
     my $self = shift;
     my $git = $self->git;
 
-    my $output = capture_merged {
-        `"$git" pull`;
-    };
+    my $output = `"$git" pull`;
+#    my $output = capture_merged {
+#    };
     return $output;
 }
 1;
